@@ -30,7 +30,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.93.0.
+This document is Muldis::D version 0.94.0.
 
 =head1 PREFACE
 
@@ -46,8 +46,8 @@ L<Muldis::D::Ext::Integer>, L<Muldis::D::Ext::Blob>,
 L<Muldis::D::Ext::Text>, L<Muldis::D::Ext::Rational>,
 L<Muldis::D::Ext::Tuple>, L<Muldis::D::Ext::Relation>,
 L<Muldis::D::Ext::Set>, L<Muldis::D::Ext::Array>, L<Muldis::D::Ext::Bag>,
-L<Muldis::D::Ext::Counted>, L<Muldis::D::Ext::Temporal>,
-L<Muldis::D::Ext::Spatial>.
+L<Muldis::D::Ext::Interval>, L<Muldis::D::Ext::Counted>,
+L<Muldis::D::Ext::Temporal>, L<Muldis::D::Ext::Spatial>.
 
 =head1 DESCRIPTION
 
@@ -60,9 +60,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:"http://muldis.com":"0.93.0">.  It is the official/original (not
+C<Muldis_D:"http://muldis.com":"0.94.0">.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.93.0> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.94.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
